function G = FRFT(x,beta);

% Fractional fast Fourier transform
% Uses the Matlab functions fft() and ifft() for the FFT and inverse FFT
% Input:
%   x = a vector of values
%   beta = increment parameter

N = length(x);

% Construct the y and z vectors
y = [exp(-i.*pi.*(0:N-1).^2.*beta).*x  ones(1,N)];
z = [exp( i.*pi.*(0:N-1).^2.*beta)     exp(i.*pi.*(N:-1:1).^2.*beta)];

% FFT on y and z
Dy = fft(y);
Dz = fft(z);

% Inverse FFT on the FFTs of y and z
iDyDz = ifft(Dy.*Dz);

% The FRFT
G = exp(-i.*pi.*(0:N-1).^2.*beta).*iDyDz(1:N);

